@@ -10,12 +10,18 @@ from .utils import StatsModel
 __all__ = []
 
 game_modes = [
-    "classic",
-    "op",
-    "uhc",
-    "sumo",
-    "bridge",
-    "sw"
+    "classic_duel",
+    "op_duel",
+    "uhc_duel",
+    "sumo_duel",
+    "bridge_duel",
+    "sw_duel",
+    "uhc_doubles",
+    "bridge_doubles",
+    "op_doubles",
+    "uhc_meetup",
+    "bow_duel",
+    "combo_duel"
 ]
 
 class OverallDuelStats(BaseModel):
@@ -28,8 +34,8 @@ class OverallDuelStats(BaseModel):
     @property
     def recent_games(self) -> list[str]:
         return self.recent_games_object.lower().split("#")
-    games_played: int = Field(0, alias="games_played_duels")
     current_winstreak: int = 0
+    games_played: int = Field(0, alias="games_played_duels")
     bow_shots: int = 0
     bow_hits: int = 0
     coins: int = 0
@@ -45,6 +51,7 @@ class OverallDuelStats(BaseModel):
     blocks_placed: int = 0
     golden_apples_eaten: int = 0
     goals: int = 0
+    duel_title: str = Field("", alias="active_cosmetictitle")
 
 class ClassicDuelStats(StatsModel):
     """Classic duel stats.
@@ -54,7 +61,6 @@ class ClassicDuelStats(StatsModel):
     _prefix: str = "classic_duel_"
     _suffix: str = "_mode_classic_duel"
     _game_mode: str = "classic_duel"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     bow_shots: int = 0
@@ -78,7 +84,6 @@ class OPDuelStats(StatsModel):
     _prefix: str = "op_duel_"
     _suffix: str = "_mode_op_duel"
     _game_mode: str = "op_duel"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     damage_dealt: int = 0
@@ -100,7 +105,6 @@ class UHCDuelStats(StatsModel):
     _prefix: str = "uhc_duel_"
     _suffix: str = "_mode_uhc_duel"
     _game_mode: str = "uhc_duel"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     bow_shots: int = 0
@@ -123,7 +127,6 @@ class SumoDuelStats(StatsModel):
     _prefix: str = "sumo_duel_"
     _suffix: str = "_mode_sumo_duel"
     _game_mode: str = "sumo_duel"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     deaths: int = 0
@@ -143,7 +146,6 @@ class BridgeDuelStats(StatsModel):
     _prefix: str = "bridge_duel_"
     _suffix: str = "_mode_bridge_duel"
     _game_mode: str = "bridge_duel"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     bow_shots: int = 0
@@ -169,7 +171,6 @@ class SkyWarsDuelStats(StatsModel):
     _prefix: str = "sw_duel_"
     _suffix: str = "_mode_sw_duel"
     _game_mode: str = "sw_duel"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     blocks_placed: int = 0
@@ -193,7 +194,6 @@ class UHCDoubleStats(StatsModel):
     _prefix: str = "uhc_doubles_"
     _suffix: str = "_mode_uhc_doubles"
     _game_mode: str = "uhc_doubles"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     blocks_placed: int = 0
@@ -219,7 +219,6 @@ class BridgeDoubleStats(StatsModel):
     _prefix: str = "bridge_doubles_"
     _suffix: str = "_mode_bridge_doubles"
     _game_mode: str = "bridge_doubles"
-    _game_modes: List[str] = game_modes
 
     current_winstreak: int = 0
     blocks_placed: int = 0
@@ -235,4 +234,78 @@ class BridgeDoubleStats(StatsModel):
     melee_swings: int = 0
     games_played: int = Field(0, alias="rounds_played")
     best_winstreak: int = 0
-    wins: int = 0
\ No newline at end of file
+    wins: int = 0
+
+class OPDoubleStats(StatsModel):
+    """OP double stats.
+    
+    Any stats to do with hearts are measured in halves.
+    """
+    _prefix: str = "op_doubles_"
+    _suffix: str = "_mode_op_doubles"
+    _game_mode: str = "op_doubles"
+
+    current_winstreak: int = 0
+    damage_dealt: int = 0
+    deaths: int = 0
+    health_regenerated: int = 0
+    losses: int = 0
+    melee_hits: int = 0
+    melee_swings: int = 0
+    games_played: int = Field(0, alias="rounds_played")
+    kills: int = 0
+    best_winstreak: int = 0
+    wins: int = 0
+
+class UHCMeetupStats(StatsModel):
+    """UHC meetup(deathmatch) stats.
+    
+    Any stats to do with hearts are measured in halves.
+    """
+    _prefix: str = "uhc_meetup_"
+    _suffix: str = "_mode_uhc_meetup"
+    _game_mode: str = "uhc_meetup"
+
+    current_winstreak: int = 0
+    blocks_placed: int = 0
+    bow_hits: int = 0
+    bow_shots: int = 0
+    damage_dealt: int = 0
+    deaths: int = 0
+    health_regenerated: int = 0
+    losses: int = 0
+    melee_hits: int = 0
+    melee_swings: int = 0
+    games_played: int = Field(0, alias="rounds_played")
+    kills: int = 0
+
+#The next two classes dont inherit from the main stats base class because there is already a little amount of stats in them.
+class BowDuelStats(StatsModel):
+    """Bow duel stats.
+    
+    Any stats to do with hearts are measured in halves.
+    """
+    _prefix: str = "bow_duel_"
+    _game_mode: str = "bow_duel"
+    _game_modes: List[str] = game_modes
+
+    bow_hits: int = 0
+    bow_shots: int = 0
+    damage_dealt: int = 0
+    health_regenerated: int = 0
+    games_played: int = Field(0, alias="rounds_played")
+
+class ComboDuelStats(StatsModel):
+    """Combo duel stats.
+    
+    Any stats to do with hearts are measured in halves.
+    """
+    _prefix: str = "combo_duel_"
+    _game_mode: str = "combo_duel"
+    _game_modes: List[str] = game_modes
+
+    damage_dealt: int = 0
+    health_regenerated: int = 0
+    melee_hits: int = 0
+    melee_swings: int = 0
+    games_played: int = Field(0, alias="rounds_played")
\ No newline at end of file
